{% extends "modeladmin/inspect.html" %}
{% load i18n wagtailadmin_tags %}

{% block content_main %}
    <div class="nice-padding">
        <a href="{{ view.index_url }}" class="button button-small bicolor button--icon">
            <span class="icon-wrapper">
                <svg class="icon icon-arrow-left" aria-hidden="true" focusable="false">
                    <use href="#icon-arrow-left"></use>
                </svg>
            </span>

            {% blocktrans with view.verbose_name as model_name %}Back to {{ model_name }} list{% endblocktrans %}
        </a>

        {% block fields_output %}
            {% if fields %}
                <div style="margin-top:24px;">
                    {% for field in fields %}
                        <div style="padding:12px 0; border-bottom:solid 1px #ccc;">
                            <span style="margin-right:24px;">{{field.label}}:</span>
                            <span style="font-weight:bold;">{{field.value}}</span>
                        </div>
                    {% endfor %}
                </div>
            {% endif %}
        {% endblock %}
    </div>
{% endblock %}