{% extends "admin/change_list.html" %}
{% load i18n admin_urls %}

{% block object-tools-items %}
    {% if 'cookieconsentlog' in request.path %}
        <li>
            <a href="{% url 'export_django' %}" class="grp-state-focus addlink">{% trans 'Esporta dati CSV' %}</a>
        </li>
    {% endif %}

    {{ block.super }}
{% endblock %}